@@ -164,19 +164,20 @@ def test_is_key_list(given, expected):
             Optional('locals', default=''): str,
             'configs': str,
             'keys': Or([str], empty_list),
+            Optional('cast', default='lambda x: x'): eval,
             **error_or(
                 expected=str,
             ),
         })
 )
-def test_key_map_from_key_list(locals, configs, keys, expected, error):
+def test_key_map_from_key_list(locals, configs, keys, cast, expected, error):
     shared = locals_or_ab(locals)
     configs = eval(configs, {}, shared)
     keys = [eval(x, {}, shared) for x in keys]
     expected = eval(expected or 'None', shared)
 
     with error:
-        map = appcli.params._key_map_from_key_list(configs, keys)
+        map = appcli.params._key_map_from_key_list(configs, keys, cast)
         assert wrap_key_map(map, 0) == expected
 
 @parametrize_from_file(
